function create_operator(azimuth, elevation, data_set)
%function create_operator(azimuth, elevation, data_set)
% Load an HRTF, convert to matrix-form operator
% 
% phubbard@computer.org and umland@math.unm.edu
% pfh/ku 4/99, now using wavelab functions
% Modified 4/30/99 to use Matlab function to produce a circulant
% matrix using the Toeplitz function. 
% News to me, but orders of magnitude faster!

% Save starting time
begin_time = clock;
begin_flops = cputime;

% Filter length
filter_length = 512;

% Sample rate of filter; must be power of two
sample_rate = 44100;

% We will pad each HRTF out to 2x its length
padded_length = 4 * filter_length;
num_pads = padded_length - filter_length;

% Call the Gardner function to load the time-domain HRTF
% Produces a 2x512 array, left channel in 1, right in 2
disp 'Reading HRTF from file'
hrtf = readhrtf(elevation, azimuth, data_set);
disp 'done.'

% Allocate sparse matrix to hold circulant
disp 'Allocating arrays and copying HRTFs'

num_nz = (filter_length + 1) ^2;
op_left = spalloc(padded_length, padded_length, num_nz);
op_right = spalloc(padded_length, padded_length, num_nz);

padded_hrtf = zeros(padded_length, 2);
padded_hrtf(:,1) = [hrtf(1,:) zeros(1, num_pads)]';
padded_hrtf(:,2) = [hrtf(2,:) zeros(1, num_pads)]';

disp 'Creating circulant matrix'
op_left = sparse(circulant(padded_hrtf(:,1)))';
op_right = sparse(circulant(padded_hrtf(:,2)))';

% Save the results into a file
disp 'Saving results...'
save oright.mat op_right
save oleft.mat op_left

% Show how hard we worked
end_time = clock;

sprintf('Elapsed time: %s seconds CPU seconds: %d', etime(end_time, begin_time), ...
	cputime - begin_flops)

